@@ -10,20 +10,24 @@ insDoc(aux1, gLnk("R", "ABHeight", "vars/Time-Dependent.html#ABHeight"))
 insDoc(aux1, gLnk("R", "AbsorbingBoundaries", "vars/Time-Dependent.html#AbsorbingBoundaries"))
 insDoc(aux1, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
 insDoc(aux1, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
+insDoc(aux1, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
 insDoc(aux1, gLnk("R", "AnimationSampling", "vars/Utilities.html#AnimationSampling"))
+insDoc(aux1, gLnk("R", "ArpackInitialTolerance", "vars/SCF.html#ArpackInitialTolerance"))
 insDoc(aux1, gLnk("R", "AtomsMagnetDirection", "vars/SCF.html#AtomsMagnetDirection"))
 insDoc(aux1, gLnk("R", "AxisType", "vars/Utilities.html#AxisType"))
 aux1 = insFld(aux0, gFld("B", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "BerkeleyGW_CalcDipoleMtxels", "vars/Output.html#BerkeleyGW_CalcDipoleMtxels"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_CalcExchange", "vars/Output.html#BerkeleyGW_CalcExchange"))
-insDoc(aux1, gLnk("R", "BerkeleyGW_Complex", "vars/Output.html#BerkeleyGW_Complex"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_NumberBands", "vars/Output.html#BerkeleyGW_NumberBands"))
+insDoc(aux1, gLnk("R", "BerkeleyGW_VmtxelNumCondBands", "vars/Output.html#BerkeleyGW_VmtxelNumCondBands"))
+insDoc(aux1, gLnk("R", "BerkeleyGW_VmtxelNumValBands", "vars/Output.html#BerkeleyGW_VmtxelNumValBands"))
+insDoc(aux1, gLnk("R", "BerkeleyGW_VmtxelPolarization", "vars/Output.html#BerkeleyGW_VmtxelPolarization"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_Vxc_diag_nmax", "vars/Output.html#BerkeleyGW_Vxc_diag_nmax"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_Vxc_diag_nmin", "vars/Output.html#BerkeleyGW_Vxc_diag_nmin"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmax", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmax"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmin", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmin"))
 insDoc(aux1, gLnk("R", "BerkeleyGW_WFN_filename", "vars/Output.html#BerkeleyGW_WFN_filename"))
 insDoc(aux1, gLnk("R", "BornChargeSumRuleCorrection", "vars/Linear_Response.html#BornChargeSumRuleCorrection"))
-insDoc(aux1, gLnk("R", "BoxOffset", "vars/Mesh.html#BoxOffset"))
 insDoc(aux1, gLnk("R", "BoxShape", "vars/Mesh.html#BoxShape"))
 insDoc(aux1, gLnk("R", "BoxShapeImage", "vars/Mesh.html#BoxShapeImage"))
 insDoc(aux1, gLnk("R", "BoxShapeUsDef", "vars/Mesh.html#BoxShapeUsDef"))
@@ -32,31 +36,55 @@ insDoc(aux1, gLnk("R", "CalcInfrared", "vars/Linear_Response.html#CalcInfrared")
 insDoc(aux1, gLnk("R", "CalcNormalModeWfs", "vars/Linear_Response.html#CalcNormalModeWfs"))
 insDoc(aux1, gLnk("R", "CalculateSelfInducedMagneticField", "vars/Hamiltonian.html#CalculateSelfInducedMagneticField"))
 insDoc(aux1, gLnk("R", "CalculationMode", "vars/Calculation_Modes.html#CalculationMode"))
+insDoc(aux1, gLnk("R", "CasidaCalcForces", "vars/Linear_Response.html#CasidaCalcForces"))
+insDoc(aux1, gLnk("R", "CasidaCalcForcesKernel", "vars/Linear_Response.html#CasidaCalcForcesKernel"))
+insDoc(aux1, gLnk("R", "CasidaCalcForcesSCF", "vars/Linear_Response.html#CasidaCalcForcesSCF"))
 insDoc(aux1, gLnk("R", "CasidaCalcTriplet", "vars/Linear_Response.html#CasidaCalcTriplet"))
+insDoc(aux1, gLnk("R", "CasidaHermitianConjugate", "vars/Linear_Response.html#CasidaHermitianConjugate"))
 insDoc(aux1, gLnk("R", "CasidaKohnShamStates", "vars/Linear_Response.html#CasidaKohnShamStates"))
+insDoc(aux1, gLnk("R", "CasidaKSEnergyWindow", "vars/Linear_Response.html#CasidaKSEnergyWindow"))
 insDoc(aux1, gLnk("R", "CasidaMomentumTransfer", "vars/Linear_Response.html#CasidaMomentumTransfer"))
 insDoc(aux1, gLnk("R", "CasidaQuadratureOrder", "vars/Linear_Response.html#CasidaQuadratureOrder"))
 insDoc(aux1, gLnk("R", "CasidaSpectrumBroadening", "vars/Utilities.html#CasidaSpectrumBroadening"))
 insDoc(aux1, gLnk("R", "CasidaSpectrumEnergyStep", "vars/Utilities.html#CasidaSpectrumEnergyStep"))
 insDoc(aux1, gLnk("R", "CasidaSpectrumMaxEnergy", "vars/Utilities.html#CasidaSpectrumMaxEnergy"))
 insDoc(aux1, gLnk("R", "CasidaSpectrumMinEnergy", "vars/Utilities.html#CasidaSpectrumMinEnergy"))
+insDoc(aux1, gLnk("R", "CasidaSpectrumRotationMatrix", "vars/Utilities.html#CasidaSpectrumRotationMatrix"))
 insDoc(aux1, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
 insDoc(aux1, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
+insDoc(aux1, gLnk("R", "CavityGeometry", "vars/Hamiltonian.html#CavityGeometry"))
 insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
-insDoc(aux1, gLnk("R", "ComplexBoundaries", "vars/System.html#ComplexBoundaries"))
 insDoc(aux1, gLnk("R", "ComplexScaling", "vars/Hamiltonian.html#ComplexScaling"))
-insDoc(aux1, gLnk("R", "ComplexScalingAngle", "vars/Hamiltonian.html#ComplexScalingAngle"))
+insDoc(aux1, gLnk("R", "ComplexScalingAlpha", "vars/Hamiltonian.html#ComplexScalingAlpha"))
+insDoc(aux1, gLnk("R", "ComplexScalingAlphaLeft", "vars/Hamiltonian.html#ComplexScalingAlphaLeft"))
+insDoc(aux1, gLnk("R", "ComplexScalingLocalizationRadius", "vars/Hamiltonian.html#ComplexScalingLocalizationRadius"))
+insDoc(aux1, gLnk("R", "ComplexScalingLocalizationThreshold", "vars/Hamiltonian.html#ComplexScalingLocalizationThreshold"))
+insDoc(aux1, gLnk("R", "ComplexScalingLocalizedStates", "vars/Hamiltonian.html#ComplexScalingLocalizedStates"))
+insDoc(aux1, gLnk("R", "ComplexScalingPenalizationFactor", "vars/Hamiltonian.html#ComplexScalingPenalizationFactor"))
+insDoc(aux1, gLnk("R", "ComplexScalingRotateSpectrum", "vars/Hamiltonian.html#ComplexScalingRotateSpectrum"))
+insDoc(aux1, gLnk("R", "ComplexScalingTheta", "vars/Hamiltonian.html#ComplexScalingTheta"))
 insDoc(aux1, gLnk("R", "ConvAbsDens", "vars/SCF.html#ConvAbsDens"))
 insDoc(aux1, gLnk("R", "ConvAbsEv", "vars/SCF.html#ConvAbsEv"))
 insDoc(aux1, gLnk("R", "ConvEigenError", "vars/SCF.html#ConvEigenError"))
+insDoc(aux1, gLnk("R", "ConvertEnd", "vars/Utilities.html#ConvertEnd"))
+insDoc(aux1, gLnk("R", "ConvertEnergyMax", "vars/Utilities.html#ConvertEnergyMax"))
+insDoc(aux1, gLnk("R", "ConvertEnergyMin", "vars/Utilities.html#ConvertEnergyMin"))
+insDoc(aux1, gLnk("R", "ConvertFilename", "vars/Utilities.html#ConvertFilename"))
+insDoc(aux1, gLnk("R", "ConvertFolder", "vars/Utilities.html#ConvertFolder"))
+insDoc(aux1, gLnk("R", "ConvertIterateFolder", "vars/Utilities.html#ConvertIterateFolder"))
+insDoc(aux1, gLnk("R", "ConvertReadSize", "vars/Utilities.html#ConvertReadSize"))
+insDoc(aux1, gLnk("R", "ConvertStart", "vars/Utilities.html#ConvertStart"))
+insDoc(aux1, gLnk("R", "ConvertStep", "vars/Utilities.html#ConvertStep"))
+insDoc(aux1, gLnk("R", "ConvertSubtract", "vars/Utilities.html#ConvertSubtract"))
+insDoc(aux1, gLnk("R", "ConvertSubtractFilename", "vars/Utilities.html#ConvertSubtractFilename"))
+insDoc(aux1, gLnk("R", "ConvertSubtractFolder", "vars/Utilities.html#ConvertSubtractFolder"))
+insDoc(aux1, gLnk("R", "ConvertTransform", "vars/Utilities.html#ConvertTransform"))
 insDoc(aux1, gLnk("R", "ConvForce", "vars/SCF.html#ConvForce"))
 insDoc(aux1, gLnk("R", "ConvRelDens", "vars/SCF.html#ConvRelDens"))
 insDoc(aux1, gLnk("R", "ConvRelEv", "vars/SCF.html#ConvRelEv"))
 insDoc(aux1, gLnk("R", "Coordinates", "vars/System.html#Coordinates"))
-insDoc(aux1, gLnk("R", "CPElectronicMass", "vars/Time-Dependent.html#CPElectronicMass"))
-insDoc(aux1, gLnk("R", "CPMethod", "vars/Time-Dependent.html#CPMethod"))
-insDoc(aux1, gLnk("R", "CurrentInTau", "vars/States.html#CurrentInTau"))
-insDoc(aux1, gLnk("R", "CurrentThroughPlane", "vars/States.html#CurrentThroughPlane"))
+insDoc(aux1, gLnk("R", "CurrentDensity", "vars/Hamiltonian.html#CurrentDensity"))
+insDoc(aux1, gLnk("R", "CurrentThroughPlane", "vars/Output.html#CurrentThroughPlane"))
 insDoc(aux1, gLnk("R", "CurvGygiA", "vars/Mesh.html#CurvGygiA"))
 insDoc(aux1, gLnk("R", "CurvGygiAlpha", "vars/Mesh.html#CurvGygiAlpha"))
 insDoc(aux1, gLnk("R", "CurvGygiBeta", "vars/Mesh.html#CurvGygiBeta"))
@@ -86,10 +114,13 @@ insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
 aux1 = insFld(aux0, gFld("E", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
 insDoc(aux1, gLnk("R", "EigensolverArnoldiVectors", "vars/SCF.html#EigensolverArnoldiVectors"))
+insDoc(aux1, gLnk("R", "EigensolverArpackInitialResid", "vars/SCF.html#EigensolverArpackInitialResid"))
+insDoc(aux1, gLnk("R", "EigensolverArpackSort", "vars/SCF.html#EigensolverArpackSort"))
 insDoc(aux1, gLnk("R", "EigensolverImaginaryTime", "vars/SCF.html#EigensolverImaginaryTime"))
 insDoc(aux1, gLnk("R", "EigensolverMaxIter", "vars/SCF.html#EigensolverMaxIter"))
 insDoc(aux1, gLnk("R", "EigensolverMinimizationIter", "vars/SCF.html#EigensolverMinimizationIter"))
-insDoc(aux1, gLnk("R", "EigensolverSubspaceDiag", "vars/SCF.html#EigensolverSubspaceDiag"))
+insDoc(aux1, gLnk("R", "EigensolverParpack", "vars/SCF.html#EigensolverParpack"))
+insDoc(aux1, gLnk("R", "EigensolverSaveMemory", "vars/SCF.html#EigensolverSaveMemory"))
 insDoc(aux1, gLnk("R", "EigensolverTolerance", "vars/SCF.html#EigensolverTolerance"))
 insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
 insDoc(aux1, gLnk("R", "EMCalcBornCharges", "vars/Linear_Response.html#EMCalcBornCharges"))
@@ -111,18 +142,21 @@ insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
 insDoc(aux1, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
 insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
 aux1 = insFld(aux0, gFld("F", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "FeastContour", "vars/SCF.html#FeastContour"))
+insDoc(aux1, gLnk("R", "FeastMaxIter", "vars/SCF.html#FeastMaxIter"))
 insDoc(aux1, gLnk("R", "FFTLibrary", "vars/Mesh.html#FFTLibrary"))
 insDoc(aux1, gLnk("R", "FFTOptimize", "vars/Mesh.html#FFTOptimize"))
 insDoc(aux1, gLnk("R", "FFTPreparePlan", "vars/Mesh.html#FFTPreparePlan"))
 insDoc(aux1, gLnk("R", "FilterPotentials", "vars/Hamiltonian.html#FilterPotentials"))
 insDoc(aux1, gLnk("R", "FlushMessages", "vars/Execution.html#FlushMessages"))
 insDoc(aux1, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
+insDoc(aux1, gLnk("R", "ForceTotalEnforce", "vars/Hamiltonian.html#ForceTotalEnforce"))
 insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
-insDoc(aux1, gLnk("R", "FrozenSystems", "vars/States.html#FrozenSystems"))
 aux1 = insFld(aux0, gFld("G", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "GaugeVectorField", "vars/Hamiltonian.html#GaugeVectorField"))
 insDoc(aux1, gLnk("R", "GCMSlaterDeterminants", "vars/Calculation_Modes.html#GCMSlaterDeterminants"))
 insDoc(aux1, gLnk("R", "GOCenter", "vars/Calculation_Modes.html#GOCenter"))
+insDoc(aux1, gLnk("R", "GOLineTol", "vars/Calculation_Modes.html#GOLineTol"))
 insDoc(aux1, gLnk("R", "GOMaxIter", "vars/Calculation_Modes.html#GOMaxIter"))
 insDoc(aux1, gLnk("R", "GOMethod", "vars/Calculation_Modes.html#GOMethod"))
 insDoc(aux1, gLnk("R", "GOMinimumMove", "vars/Calculation_Modes.html#GOMinimumMove"))
@@ -144,6 +178,7 @@ insDoc(aux1, gLnk("R", "InvertKSStabilizer", "vars/Calculation_Modes.html#Invert
 insDoc(aux1, gLnk("R", "InvertKSTargetDensity", "vars/Calculation_Modes.html#InvertKSTargetDensity"))
 insDoc(aux1, gLnk("R", "InvertKSVerbosity", "vars/Calculation_Modes.html#InvertKSVerbosity"))
 insDoc(aux1, gLnk("R", "IonicInteraction", "vars/System.html#IonicInteraction"))
+insDoc(aux1, gLnk("R", "IonsConstantVelocity", "vars/Time-Dependent.html#IonsConstantVelocity"))
 aux1 = insFld(aux0, gFld("K", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "KdotPCalcSecondOrder", "vars/Linear_Response.html#KdotPCalcSecondOrder"))
 insDoc(aux1, gLnk("R", "KdotPCalculateEffectiveMasses", "vars/Linear_Response.html#KdotPCalculateEffectiveMasses"))
@@ -155,22 +190,39 @@ insDoc(aux1, gLnk("R", "KPointsGrid", "vars/Mesh.html#KPointsGrid"))
 insDoc(aux1, gLnk("R", "KPointsReduced", "vars/Mesh.html#KPointsReduced"))
 insDoc(aux1, gLnk("R", "KPointsUseSymmetries", "vars/Mesh.html#KPointsUseSymmetries"))
 insDoc(aux1, gLnk("R", "KPointsUseTimeReversal", "vars/Mesh.html#KPointsUseTimeReversal"))
-insDoc(aux1, gLnk("R", "KSInversionLevel", "vars/Hamiltonian.html#KSInversionLevel"))
+insDoc(aux1, gLnk("R", "KSInversionLevel", "vars/Calculation_Modes.html#KSInversionLevel"))
 aux1 = insFld(aux0, gFld("L", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "LatticeVectors", "vars/Mesh.html#LatticeVectors"))
+insDoc(aux1, gLnk("R", "LB94_modified", "vars/Hamiltonian.html#LB94_modified"))
+insDoc(aux1, gLnk("R", "LB94_threshold", "vars/Hamiltonian.html#LB94_threshold"))
 insDoc(aux1, gLnk("R", "LCAOAlternative", "vars/SCF.html#LCAOAlternative"))
+insDoc(aux1, gLnk("R", "LCAOComplexYlms", "vars/SCF.html#LCAOComplexYlms"))
 insDoc(aux1, gLnk("R", "LCAODiagTol", "vars/SCF.html#LCAODiagTol"))
 insDoc(aux1, gLnk("R", "LCAODimension", "vars/SCF.html#LCAODimension"))
 insDoc(aux1, gLnk("R", "LCAOExtraOrbitals", "vars/SCF.html#LCAOExtraOrbitals"))
 insDoc(aux1, gLnk("R", "LCAOKeepOrbitals", "vars/SCF.html#LCAOKeepOrbitals"))
+insDoc(aux1, gLnk("R", "LCAOMaximumOrbitalRadius", "vars/SCF.html#LCAOMaximumOrbitalRadius"))
+insDoc(aux1, gLnk("R", "LCAOScaleFactor", "vars/SCF.html#LCAOScaleFactor"))
 insDoc(aux1, gLnk("R", "LCAOStart", "vars/SCF.html#LCAOStart"))
+insDoc(aux1, gLnk("R", "LDBaderThreshold", "vars/Utilities.html#LDBaderThreshold"))
+insDoc(aux1, gLnk("R", "LDExtraWrite", "vars/Utilities.html#LDExtraWrite"))
+insDoc(aux1, gLnk("R", "LDFilename", "vars/Utilities.html#LDFilename"))
+insDoc(aux1, gLnk("R", "LDFolder", "vars/Utilities.html#LDFolder"))
+insDoc(aux1, gLnk("R", "LDMultipoleLmax", "vars/Utilities.html#LDMultipoleLmax"))
+insDoc(aux1, gLnk("R", "LDOutput", "vars/Utilities.html#LDOutput"))
+insDoc(aux1, gLnk("R", "LDOutputHow", "vars/Utilities.html#LDOutputHow"))
+insDoc(aux1, gLnk("R", "LDOverWrite", "vars/Utilities.html#LDOverWrite"))
+insDoc(aux1, gLnk("R", "LDRadiiFile", "vars/Utilities.html#LDRadiiFile"))
+insDoc(aux1, gLnk("R", "LDUpdate", "vars/Utilities.html#LDUpdate"))
 insDoc(aux1, gLnk("R", "LinearSolver", "vars/Linear_Response.html#LinearSolver"))
 insDoc(aux1, gLnk("R", "LinearSolverMaxIter", "vars/Linear_Response.html#LinearSolverMaxIter"))
 insDoc(aux1, gLnk("R", "LiquidDensity", "vars/Utilities.html#LiquidDensity"))
 insDoc(aux1, gLnk("R", "LiquidMoleculeScale", "vars/Utilities.html#LiquidMoleculeScale"))
 insDoc(aux1, gLnk("R", "LiquidNumberOfMolecules", "vars/Utilities.html#LiquidNumberOfMolecules"))
+insDoc(aux1, gLnk("R", "LocalDomain", "vars/Utilities.html#LocalDomain"))
 insDoc(aux1, gLnk("R", "LocalMagneticMomentsSphereRadius", "vars/Output.html#LocalMagneticMomentsSphereRadius"))
 insDoc(aux1, gLnk("R", "LRConvAbsDens", "vars/Linear_Response.html#LRConvAbsDens"))
+insDoc(aux1, gLnk("R", "LRConvRelDens", "vars/Linear_Response.html#LRConvRelDens"))
 insDoc(aux1, gLnk("R", "LRMaximumIter", "vars/Linear_Response.html#LRMaximumIter"))
 insDoc(aux1, gLnk("R", "LRTolAdaptiveFactor", "vars/Linear_Response.html#LRTolAdaptiveFactor"))
 insDoc(aux1, gLnk("R", "LRTolFinalTol", "vars/Linear_Response.html#LRTolFinalTol"))
@@ -188,18 +240,19 @@ insDoc(aux1, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
 insDoc(aux1, gLnk("R", "MemoryMaxIter", "vars/Time-Dependent.html#MemoryMaxIter"))
 insDoc(aux1, gLnk("R", "MemoryTol", "vars/Time-Dependent.html#MemoryTol"))
 insDoc(aux1, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
+insDoc(aux1, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
 insDoc(aux1, gLnk("R", "MeshPartition", "vars/Execution.html#MeshPartition"))
-insDoc(aux1, gLnk("R", "MeshPartitionFromScratch", "vars/Execution.html#MeshPartitionFromScratch"))
-insDoc(aux1, gLnk("R", "MeshPartitionGAMaxSteps", "vars/Execution.html#MeshPartitionGAMaxSteps"))
-insDoc(aux1, gLnk("R", "MeshPartitionGAPopulation", "vars/Execution.html#MeshPartitionGAPopulation"))
+insDoc(aux1, gLnk("R", "MeshPartitionDir", "vars/Execution.html#MeshPartitionDir"))
 insDoc(aux1, gLnk("R", "MeshPartitionPackage", "vars/Execution.html#MeshPartitionPackage"))
+insDoc(aux1, gLnk("R", "MeshPartitionRead", "vars/Execution.html#MeshPartitionRead"))
 insDoc(aux1, gLnk("R", "MeshPartitionStencil", "vars/Execution.html#MeshPartitionStencil"))
+insDoc(aux1, gLnk("R", "MeshPartitionVirtualSize", "vars/Execution.html#MeshPartitionVirtualSize"))
+insDoc(aux1, gLnk("R", "MeshPartitionWrite", "vars/Execution.html#MeshPartitionWrite"))
 insDoc(aux1, gLnk("R", "MeshUseTopology", "vars/Execution.html#MeshUseTopology"))
-insDoc(aux1, gLnk("R", "MGGAimplementation", "vars/Hamiltonian.html#MGGAimplementation"))
 insDoc(aux1, gLnk("R", "MixField", "vars/SCF.html#MixField"))
 insDoc(aux1, gLnk("R", "Mixing", "vars/SCF.html#Mixing"))
 insDoc(aux1, gLnk("R", "MixNumberSteps", "vars/SCF.html#MixNumberSteps"))
-insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/States.html#MomentumTransfer"))
+insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/Output.html#MomentumTransfer"))
 insDoc(aux1, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
 insDoc(aux1, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
 insDoc(aux1, gLnk("R", "MultigridLevels", "vars/Mesh.html#MultigridLevels"))
@@ -214,35 +267,37 @@ insDoc(aux1, gLnk("R", "NFFTPrecompute", "vars/Mesh.html#NFFTPrecompute"))
 insDoc(aux1, gLnk("R", "NLOperatorCompactBoundaries", "vars/Execution.html#NLOperatorCompactBoundaries"))
 insDoc(aux1, gLnk("R", "NParticleModelmb", "vars/States.html#NParticleModelmb"))
 insDoc(aux1, gLnk("R", "NTypeParticleModelmb", "vars/States.html#NTypeParticleModelmb"))
-insDoc(aux1, gLnk("R", "NumberUnoccStates", "vars/Calculation_Modes.html#NumberUnoccStates"))
 aux1 = insFld(aux0, gFld("O", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Occupations", "vars/States.html#Occupations"))
 insDoc(aux1, gLnk("R", "OCTCheckGradient", "vars/Calculation_Modes.html#OCTCheckGradient"))
+insDoc(aux1, gLnk("R", "OCTClassicalTarget", "vars/Calculation_Modes.html#OCTClassicalTarget"))
 insDoc(aux1, gLnk("R", "OCTControlFunctionOmegaMax", "vars/Calculation_Modes.html#OCTControlFunctionOmegaMax"))
 insDoc(aux1, gLnk("R", "OCTControlFunctionRepresentation", "vars/Calculation_Modes.html#OCTControlFunctionRepresentation"))
 insDoc(aux1, gLnk("R", "OCTControlFunctionType", "vars/Calculation_Modes.html#OCTControlFunctionType"))
-insDoc(aux1, gLnk("R", "OCTControlRepresentation", "vars/Calculation_Modes.html#OCTControlRepresentation"))
 insDoc(aux1, gLnk("R", "OCTCurrentFunctional", "vars/Calculation_Modes.html#OCTCurrentFunctional"))
 insDoc(aux1, gLnk("R", "OCTCurrentWeight", "vars/Calculation_Modes.html#OCTCurrentWeight"))
+insDoc(aux1, gLnk("R", "OCTDelta", "vars/Calculation_Modes.html#OCTDelta"))
 insDoc(aux1, gLnk("R", "OCTDirectStep", "vars/Calculation_Modes.html#OCTDirectStep"))
 insDoc(aux1, gLnk("R", "OCTDoubleCheck", "vars/Calculation_Modes.html#OCTDoubleCheck"))
 insDoc(aux1, gLnk("R", "OCTDumpIntermediate", "vars/Calculation_Modes.html#OCTDumpIntermediate"))
 insDoc(aux1, gLnk("R", "OCTEps", "vars/Calculation_Modes.html#OCTEps"))
+insDoc(aux1, gLnk("R", "OCTEta", "vars/Calculation_Modes.html#OCTEta"))
 insDoc(aux1, gLnk("R", "OCTExcludedStates", "vars/Calculation_Modes.html#OCTExcludedStates"))
 insDoc(aux1, gLnk("R", "OCTFilter", "vars/Calculation_Modes.html#OCTFilter"))
 insDoc(aux1, gLnk("R", "OCTFixFluenceTo", "vars/Calculation_Modes.html#OCTFixFluenceTo"))
 insDoc(aux1, gLnk("R", "OCTFixInitialFluence", "vars/Calculation_Modes.html#OCTFixInitialFluence"))
+insDoc(aux1, gLnk("R", "OCTHarmonicWeight", "vars/Calculation_Modes.html#OCTHarmonicWeight"))
 insDoc(aux1, gLnk("R", "OCTInitialState", "vars/Calculation_Modes.html#OCTInitialState"))
 insDoc(aux1, gLnk("R", "OCTInitialTransformStates", "vars/Calculation_Modes.html#OCTInitialTransformStates"))
 insDoc(aux1, gLnk("R", "OCTInitialUserdefined", "vars/Calculation_Modes.html#OCTInitialUserdefined"))
 insDoc(aux1, gLnk("R", "OCTLaserEnvelope", "vars/Calculation_Modes.html#OCTLaserEnvelope"))
 insDoc(aux1, gLnk("R", "OCTLocalTarget", "vars/Calculation_Modes.html#OCTLocalTarget"))
 insDoc(aux1, gLnk("R", "OCTMaxIter", "vars/Calculation_Modes.html#OCTMaxIter"))
-insDoc(aux1, gLnk("R", "OCTMixing", "vars/Calculation_Modes.html#OCTMixing"))
-insDoc(aux1, gLnk("R", "OCTMoveIons", "vars/Calculation_Modes.html#OCTMoveIons"))
+insDoc(aux1, gLnk("R", "OCTMomentumDerivatives", "vars/Calculation_Modes.html#OCTMomentumDerivatives"))
 insDoc(aux1, gLnk("R", "OCTNumberCheckPoints", "vars/Calculation_Modes.html#OCTNumberCheckPoints"))
 insDoc(aux1, gLnk("R", "OCTOptimizeHarmonicSpectrum", "vars/Calculation_Modes.html#OCTOptimizeHarmonicSpectrum"))
 insDoc(aux1, gLnk("R", "OCTPenalty", "vars/Calculation_Modes.html#OCTPenalty"))
+insDoc(aux1, gLnk("R", "OCTPositionDerivatives", "vars/Calculation_Modes.html#OCTPositionDerivatives"))
 insDoc(aux1, gLnk("R", "OCTRandomInitialGuess", "vars/Calculation_Modes.html#OCTRandomInitialGuess"))
 insDoc(aux1, gLnk("R", "OCTScheme", "vars/Calculation_Modes.html#OCTScheme"))
 insDoc(aux1, gLnk("R", "OCTSpatialCurrWeight", "vars/Calculation_Modes.html#OCTSpatialCurrWeight"))
@@ -250,12 +305,12 @@ insDoc(aux1, gLnk("R", "OCTStartIterCurrTg", "vars/Calculation_Modes.html#OCTSta
 insDoc(aux1, gLnk("R", "OCTTargetDensity", "vars/Calculation_Modes.html#OCTTargetDensity"))
 insDoc(aux1, gLnk("R", "OCTTargetDensityFromState", "vars/Calculation_Modes.html#OCTTargetDensityFromState"))
 insDoc(aux1, gLnk("R", "OCTTargetOperator", "vars/Calculation_Modes.html#OCTTargetOperator"))
+insDoc(aux1, gLnk("R", "OCTTargetSpin", "vars/Calculation_Modes.html#OCTTargetSpin"))
 insDoc(aux1, gLnk("R", "OCTTargetTransformStates", "vars/Calculation_Modes.html#OCTTargetTransformStates"))
 insDoc(aux1, gLnk("R", "OCTTargetUserdefined", "vars/Calculation_Modes.html#OCTTargetUserdefined"))
+insDoc(aux1, gLnk("R", "OCTTdTarget", "vars/Calculation_Modes.html#OCTTdTarget"))
 insDoc(aux1, gLnk("R", "OCTVelocityDerivatives", "vars/Calculation_Modes.html#OCTVelocityDerivatives"))
 insDoc(aux1, gLnk("R", "OCTVelocityTarget", "vars/Calculation_Modes.html#OCTVelocityTarget"))
-insDoc(aux1, gLnk("R", "ODESolver", "vars/Math.html#ODESolver"))
-insDoc(aux1, gLnk("R", "ODESolverNSteps", "vars/Math.html#ODESolverNSteps"))
 insDoc(aux1, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
 insDoc(aux1, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
 insDoc(aux1, gLnk("R", "OnlyUserDefinedInitialStates", "vars/States.html#OnlyUserDefinedInitialStates"))
@@ -265,8 +320,10 @@ insDoc(aux1, gLnk("R", "OpenBoundariesMaxMemCoeffs", "vars/Open_Boundaries.html#
 insDoc(aux1, gLnk("R", "OpenBoundariesMemType", "vars/Open_Boundaries.html#OpenBoundariesMemType"))
 insDoc(aux1, gLnk("R", "OpenBoundariesQMRMaxIter", "vars/Open_Boundaries.html#OpenBoundariesQMRMaxIter"))
 insDoc(aux1, gLnk("R", "OpenBoundariesQMRTol", "vars/Open_Boundaries.html#OpenBoundariesQMRTol"))
+insDoc(aux1, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
 insDoc(aux1, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
 insDoc(aux1, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
+insDoc(aux1, gLnk("R", "OpenSCADIsovalue", "vars/Output.html#OpenSCADIsovalue"))
 insDoc(aux1, gLnk("R", "OperateComplex", "vars/Execution.html#OperateComplex"))
 insDoc(aux1, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
 insDoc(aux1, gLnk("R", "OperateOpenCL", "vars/Execution.html#OperateOpenCL"))
@@ -274,8 +331,9 @@ insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
 insDoc(aux1, gLnk("R", "OutputBandsGnuplotMode", "vars/Output.html#OutputBandsGnuplotMode"))
 insDoc(aux1, gLnk("R", "OutputBandsGraceMode", "vars/Output.html#OutputBandsGraceMode"))
 insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
-insDoc(aux1, gLnk("R", "OutputEvery", "vars/Output.html#OutputEvery"))
 insDoc(aux1, gLnk("R", "OutputHow", "vars/Output.html#OutputHow"))
+insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
+insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
 insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
 insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
 insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
@@ -287,13 +345,15 @@ insDoc(aux1, gLnk("R", "ParallelizationPoissonAllNodes", "vars/Execution.html#Pa
 insDoc(aux1, gLnk("R", "ParallelizationStrategy", "vars/Execution.html#ParallelizationStrategy"))
 insDoc(aux1, gLnk("R", "ParticleMass", "vars/Hamiltonian.html#ParticleMass"))
 insDoc(aux1, gLnk("R", "PartitionPrint", "vars/Execution.html#PartitionPrint"))
+insDoc(aux1, gLnk("R", "PDBClassical", "vars/System.html#PDBClassical"))
 insDoc(aux1, gLnk("R", "PDBCoordinates", "vars/System.html#PDBCoordinates"))
+insDoc(aux1, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
 insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
-insDoc(aux1, gLnk("R", "PESMaskEnlargeLev", "vars/Time-Dependent.html#PESMaskEnlargeLev"))
+insDoc(aux1, gLnk("R", "PESMask2PEnlargeFactor", "vars/Time-Dependent.html#PESMask2PEnlargeFactor"))
+insDoc(aux1, gLnk("R", "PESMaskEnlargeFactor", "vars/Time-Dependent.html#PESMaskEnlargeFactor"))
 insDoc(aux1, gLnk("R", "PESMaskFilterCutOff", "vars/Time-Dependent.html#PESMaskFilterCutOff"))
 insDoc(aux1, gLnk("R", "PESMaskIncludePsiA", "vars/Time-Dependent.html#PESMaskIncludePsiA"))
 insDoc(aux1, gLnk("R", "PESMaskMode", "vars/Time-Dependent.html#PESMaskMode"))
-insDoc(aux1, gLnk("R", "PESMaskNFFTEnlargeLev", "vars/Time-Dependent.html#PESMaskNFFTEnlargeLev"))
 insDoc(aux1, gLnk("R", "PESMaskOutputInterpolate", "vars/Time-Dependent.html#PESMaskOutputInterpolate"))
 insDoc(aux1, gLnk("R", "PESMaskPlaneWaveProjection", "vars/Time-Dependent.html#PESMaskPlaneWaveProjection"))
 insDoc(aux1, gLnk("R", "PESMaskPropagator", "vars/Time-Dependent.html#PESMaskPropagator"))
@@ -304,11 +364,14 @@ insDoc(aux1, gLnk("R", "PESMaskSpectEnergyStep", "vars/Time-Dependent.html#PESMa
 insDoc(aux1, gLnk("R", "PESMaskStartTime", "vars/Time-Dependent.html#PESMaskStartTime"))
 insDoc(aux1, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
 insDoc(aux1, gLnk("R", "PhotoElectronSpectrumPoints", "vars/Time-Dependent.html#PhotoElectronSpectrumPoints"))
-insDoc(aux1, gLnk("R", "Poisson1DSoftCoulomParam", "vars/Hamiltonian.html#Poisson1DSoftCoulomParam"))
+insDoc(aux1, gLnk("R", "PNFFTCutoff", "vars/Mesh.html#PNFFTCutoff"))
+insDoc(aux1, gLnk("R", "PNFFTOversampling", "vars/Mesh.html#PNFFTOversampling"))
+insDoc(aux1, gLnk("R", "Poisson1DSoftCoulombParam", "vars/Hamiltonian.html#Poisson1DSoftCoulombParam"))
 insDoc(aux1, gLnk("R", "PoissonCutoffRadius", "vars/Hamiltonian.html#PoissonCutoffRadius"))
 insDoc(aux1, gLnk("R", "PoissonFFTKernel", "vars/Hamiltonian.html#PoissonFFTKernel"))
 insDoc(aux1, gLnk("R", "PoissonSolver", "vars/Hamiltonian.html#PoissonSolver"))
 insDoc(aux1, gLnk("R", "PoissonSolverBoundaries", "vars/Hamiltonian.html#PoissonSolverBoundaries"))
+insDoc(aux1, gLnk("R", "PoissonSolverISFParallelData", "vars/Hamiltonian.html#PoissonSolverISFParallelData"))
 insDoc(aux1, gLnk("R", "PoissonSolverMaxIter", "vars/Hamiltonian.html#PoissonSolverMaxIter"))
 insDoc(aux1, gLnk("R", "PoissonSolverMaxMultipole", "vars/Hamiltonian.html#PoissonSolverMaxMultipole"))
 insDoc(aux1, gLnk("R", "PoissonSolverMGMaxCycles", "vars/Hamiltonian.html#PoissonSolverMGMaxCycles"))
@@ -329,21 +392,25 @@ insDoc(aux1, gLnk("R", "PropagationSpectrumEndTime", "vars/Utilities.html#Propag
 insDoc(aux1, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#PropagationSpectrumEnergyStep"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
-insDoc(aux1, gLnk("R", "PropagationSpectrumTimeStepFactor", "vars/Utilities.html#PropagationSpectrumTimeStepFactor"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumTransform", "vars/Utilities.html#PropagationSpectrumTransform"))
 insDoc(aux1, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#PropagationSpectrumType"))
 aux1 = insFld(aux0, gFld("R", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Radius", "vars/Mesh.html#Radius"))
 insDoc(aux1, gLnk("R", "RandomVelocityTemp", "vars/System.html#RandomVelocityTemp"))
+insDoc(aux1, gLnk("R", "RashbaSpinOrbitCoupling", "vars/Hamiltonian.html#RashbaSpinOrbitCoupling"))
+insDoc(aux1, gLnk("R", "RDMConvEner", "vars/SCF.html#RDMConvEner"))
+insDoc(aux1, gLnk("R", "RDMMaxIter", "vars/SCF.html#RDMMaxIter"))
+insDoc(aux1, gLnk("R", "RDMTolerance", "vars/SCF.html#RDMTolerance"))
 insDoc(aux1, gLnk("R", "RecalculateGSDuringEvolution", "vars/Time-Dependent.html#RecalculateGSDuringEvolution"))
 insDoc(aux1, gLnk("R", "ReducedCoordinates", "vars/System.html#ReducedCoordinates"))
 insDoc(aux1, gLnk("R", "RelativisticCorrection", "vars/Hamiltonian.html#RelativisticCorrection"))
 insDoc(aux1, gLnk("R", "ReportMemory", "vars/Execution.html#ReportMemory"))
 insDoc(aux1, gLnk("R", "ResponseMethod", "vars/Linear_Response.html#ResponseMethod"))
-insDoc(aux1, gLnk("R", "RestartDir", "vars/Execution.html#RestartDir"))
 insDoc(aux1, gLnk("R", "RestartFixedOccupations", "vars/States.html#RestartFixedOccupations"))
+insDoc(aux1, gLnk("R", "RestartOptions", "vars/Execution.html#RestartOptions"))
 insDoc(aux1, gLnk("R", "RestartReorderOccs", "vars/States.html#RestartReorderOccs"))
 insDoc(aux1, gLnk("R", "RestartWrite", "vars/Execution.html#RestartWrite"))
+insDoc(aux1, gLnk("R", "RestartWriteInterval", "vars/Execution.html#RestartWriteInterval"))
 insDoc(aux1, gLnk("R", "RootSolver", "vars/Math.html#RootSolver"))
 insDoc(aux1, gLnk("R", "RootSolverAbsTolerance", "vars/Math.html#RootSolverAbsTolerance"))
 insDoc(aux1, gLnk("R", "RootSolverHavePolynomial", "vars/Math.html#RootSolverHavePolynomial"))
@@ -351,13 +418,17 @@ insDoc(aux1, gLnk("R", "RootSolverMaxIter", "vars/Math.html#RootSolverMaxIter"))
 insDoc(aux1, gLnk("R", "RootSolverRelTolerance", "vars/Math.html#RootSolverRelTolerance"))
 insDoc(aux1, gLnk("R", "RootSolverWSRadius", "vars/Math.html#RootSolverWSRadius"))
 aux1 = insFld(aux0, gFld("S", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
 insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
 insDoc(aux1, gLnk("R", "SCFCalculateForces", "vars/SCF.html#SCFCalculateForces"))
 insDoc(aux1, gLnk("R", "SCFinLCAO", "vars/SCF.html#SCFinLCAO"))
 insDoc(aux1, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
 insDoc(aux1, gLnk("R", "Smearing", "vars/States.html#Smearing"))
+insDoc(aux1, gLnk("R", "SmearingFactor", "vars/Hamiltonian.html#SmearingFactor"))
 insDoc(aux1, gLnk("R", "SmearingFunction", "vars/States.html#SmearingFunction"))
 insDoc(aux1, gLnk("R", "SmearingMPOrder", "vars/States.html#SmearingMPOrder"))
+insDoc(aux1, gLnk("R", "Solvation", "vars/Hamiltonian.html#Solvation"))
+insDoc(aux1, gLnk("R", "SolventDielectricConstant", "vars/Hamiltonian.html#SolventDielectricConstant"))
 insDoc(aux1, gLnk("R", "SOStrength", "vars/Hamiltonian.html#SOStrength"))
 insDoc(aux1, gLnk("R", "Spacing", "vars/Mesh.html#Spacing"))
 insDoc(aux1, gLnk("R", "SPARSKITAbsTolerance", "vars/Math.html#SPARSKITAbsTolerance"))
@@ -375,7 +446,7 @@ insDoc(aux1, gLnk("R", "SpectrumSignalNoise", "vars/Utilities.html#SpectrumSigna
 insDoc(aux1, gLnk("R", "SpinComponents", "vars/States.html#SpinComponents"))
 insDoc(aux1, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
 insDoc(aux1, gLnk("R", "StatesCLDeviceMemory", "vars/Execution.html#StatesCLDeviceMemory"))
-insDoc(aux1, gLnk("R", "StatesOrthogonalization", "vars/Execution.html#StatesOrthogonalization"))
+insDoc(aux1, gLnk("R", "StatesOrthogonalization", "vars/SCF.html#StatesOrthogonalization"))
 insDoc(aux1, gLnk("R", "StatesPack", "vars/Execution.html#StatesPack"))
 insDoc(aux1, gLnk("R", "StaticElectricField", "vars/Hamiltonian.html#StaticElectricField"))
 insDoc(aux1, gLnk("R", "StaticMagneticField", "vars/Hamiltonian.html#StaticMagneticField"))
@@ -398,6 +469,7 @@ insDoc(aux1, gLnk("R", "TDExcitedStatesToProject", "vars/Time-Dependent.html#TDE
 insDoc(aux1, gLnk("R", "TDExponentialMethod", "vars/Time-Dependent.html#TDExponentialMethod"))
 insDoc(aux1, gLnk("R", "TDExpOrder", "vars/Time-Dependent.html#TDExpOrder"))
 insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalFields"))
+insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
 insDoc(aux1, gLnk("R", "TDFreezeOrbitals", "vars/Time-Dependent.html#TDFreezeOrbitals"))
 insDoc(aux1, gLnk("R", "TDFunctions", "vars/Time-Dependent.html#TDFunctions"))
 insDoc(aux1, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTimeScale"))
@@ -416,6 +488,7 @@ insDoc(aux1, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
 insDoc(aux1, gLnk("R", "TDPSFDelta", "vars/Time-Dependent.html#TDPSFDelta"))
 insDoc(aux1, gLnk("R", "TDPSFKmin", "vars/Time-Dependent.html#TDPSFKmin"))
 insDoc(aux1, gLnk("R", "TDPSFSigma", "vars/Time-Dependent.html#TDPSFSigma"))
+insDoc(aux1, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
 insDoc(aux1, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
 insDoc(aux1, gLnk("R", "TDTimeStep", "vars/Time-Dependent.html#TDTimeStep"))
 insDoc(aux1, gLnk("R", "TemperatureFunction", "vars/Time-Dependent.html#TemperatureFunction"))
@@ -424,7 +497,6 @@ insDoc(aux1, gLnk("R", "TestType", "vars/Utilities.html#TestType"))
 insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
 insDoc(aux1, gLnk("R", "Thermostat", "vars/Time-Dependent.html#Thermostat"))
 insDoc(aux1, gLnk("R", "ThermostatMass", "vars/Time-Dependent.html#ThermostatMass"))
-insDoc(aux1, gLnk("R", "TmpDir", "vars/Execution.html#TmpDir"))
 insDoc(aux1, gLnk("R", "TotalStates", "vars/States.html#TotalStates"))
 insDoc(aux1, gLnk("R", "TransformStates", "vars/States.html#TransformStates"))
 insDoc(aux1, gLnk("R", "TypeOfMixing", "vars/SCF.html#TypeOfMixing"))
@@ -432,20 +504,20 @@ aux1 = insFld(aux0, gFld("U", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "Units", "vars/Execution.html#Units"))
 insDoc(aux1, gLnk("R", "UnitsInput", "vars/Execution.html#UnitsInput"))
 insDoc(aux1, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
-insDoc(aux1, gLnk("R", "UnoccMaximumIter", "vars/Calculation_Modes.html#UnoccMaximumIter"))
 insDoc(aux1, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
 insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
 insDoc(aux1, gLnk("R", "UserDefinedStates", "vars/States.html#UserDefinedStates"))
-insDoc(aux1, gLnk("R", "UseRestartDontSolve", "vars/Linear_Response.html#UseRestartDontSolve"))
 aux1 = insFld(aux0, gFld("V", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "vdWNPoints", "vars/Linear_Response.html#vdWNPoints"))
 insDoc(aux1, gLnk("R", "Velocities", "vars/System.html#Velocities"))
 insDoc(aux1, gLnk("R", "VibrationalSpectrumTime", "vars/Utilities.html#VibrationalSpectrumTime"))
+insDoc(aux1, gLnk("R", "VibrationalSpectrumTimeStepFactor", "vars/Utilities.html#VibrationalSpectrumTimeStepFactor"))
 aux1 = insFld(aux0, gFld("W", "javascript:parent.op()"))
 insDoc(aux1, gLnk("R", "WatterstromODESolver", "vars/Math.html#WatterstromODESolver"))
 insDoc(aux1, gLnk("R", "WatterstromODESolverNSteps", "vars/Math.html#WatterstromODESolverNSteps"))
 insDoc(aux1, gLnk("R", "WorkDir", "vars/Execution.html#WorkDir"))
 aux1 = insFld(aux0, gFld("X", "javascript:parent.op()"))
+insDoc(aux1, gLnk("R", "Xalpha", "vars/Hamiltonian.html#Xalpha"))
 insDoc(aux1, gLnk("R", "XCDensityCorrection", "vars/Hamiltonian.html#XCDensityCorrection"))
 insDoc(aux1, gLnk("R", "XCDensityCorrectionCutoff", "vars/Hamiltonian.html#XCDensityCorrectionCutoff"))
 insDoc(aux1, gLnk("R", "XCDensityCorrectionMinimum", "vars/Hamiltonian.html#XCDensityCorrectionMinimum"))
@@ -453,11 +525,11 @@ insDoc(aux1, gLnk("R", "XCDensityCorrectionNormalize", "vars/Hamiltonian.html#XC
 insDoc(aux1, gLnk("R", "XCDensityCorrectionOptimize", "vars/Hamiltonian.html#XCDensityCorrectionOptimize"))
 insDoc(aux1, gLnk("R", "XCFunctional", "vars/Hamiltonian.html#XCFunctional"))
 insDoc(aux1, gLnk("R", "XCKernel", "vars/Hamiltonian.html#XCKernel"))
-insDoc(aux1, gLnk("R", "XCTailCorrection", "vars/Hamiltonian.html#XCTailCorrection"))
-insDoc(aux1, gLnk("R", "XCTailCorrectionCMDistance", "vars/Hamiltonian.html#XCTailCorrectionCMDistance"))
-insDoc(aux1, gLnk("R", "XCTailCorrectionDelay", "vars/Hamiltonian.html#XCTailCorrectionDelay"))
-insDoc(aux1, gLnk("R", "XCTailCorrectionLinkFactor", "vars/Hamiltonian.html#XCTailCorrectionLinkFactor"))
-insDoc(aux1, gLnk("R", "XCTailCorrectionTol", "vars/Hamiltonian.html#XCTailCorrectionTol"))
+insDoc(aux1, gLnk("R", "XCKernelLRCAlpha", "vars/Hamiltonian.html#XCKernelLRCAlpha"))
+insDoc(aux1, gLnk("R", "XCUseGaugeIndependentKED", "vars/Hamiltonian.html#XCUseGaugeIndependentKED"))
 insDoc(aux1, gLnk("R", "Xlength", "vars/Mesh.html#Xlength"))
+insDoc(aux1, gLnk("R", "XSFCoordinates", "vars/System.html#XSFCoordinates"))
+insDoc(aux1, gLnk("R", "XSFCoordinatesAnimStep", "vars/System.html#XSFCoordinatesAnimStep"))
+insDoc(aux1, gLnk("R", "XSFVelocities", "vars/System.html#XSFVelocities"))
 insDoc(aux1, gLnk("R", "XYZCoordinates", "vars/System.html#XYZCoordinates"))
 insDoc(aux1, gLnk("R", "XYZVelocities", "vars/System.html#XYZVelocities"))
